@@ -3,8 +3,8 @@ class TelegramData:
         self.update = None
         self.context = None
         self.telegram_id = None
-        self.user_data = None
-        self.states_data = None
+        self.udata = None
+        self.sdata = None
         self.message = None
         self.exception = None
 
@@ -13,8 +13,8 @@ class TelegramData:
             f"UPDATE {self.update}\n"
             f"CONTEXT {self.context}\n"
             f"TELEGRAM ID {self.telegram_id}\n"
-            f"USER DATA {self.user_data}\n"
-            f"STATES DATA {self.states_data}"
+            f"USER DATA {self.udata}\n"
+            f"STATES DATA {self.sdata}"
         )
 
     def update_telegram_data(self, update, context):
